==> qtjambi-qt3dcore-debuginfo-macos-5.15.17.jar: sources/QtJambi3DCore/QPropertyValueRemovedChangeBase_shell.cpp <==
#include "QPropertyValueRemovedChangeBase_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyValueRemovedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyValueRemovedChangeBase")
    Qt3DCore::QPropertyValueRemovedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QPropertyValueRemovedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyValueRemovedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyValueRemovedChangeBase_shell) ); }

jmethodID QPropertyValueRemovedChangeBase_shell::__shell_javaMethod(int pos) const { return QPropertyValueRemovedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyValueRemovedChangeBase), pos); }

// emitting (writeShellConstructor)
QPropertyValueRemovedChangeBase_shell::QPropertyValueRemovedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyValueRemovedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QPropertyValueRemovedChangeBase_shell::__shell())
    QPropertyValueRemovedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

// emitting (writeShellDestructor)
QPropertyValueRemovedChangeBase_shell::~QPropertyValueRemovedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::~Qt3DCore::QPropertyValueRemovedChangeBase()", QPropertyValueRemovedChangeBase_shell::__shell())
    QPropertyValueRemovedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

void QPropertyValueRemovedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyValueRemovedChangeBase_shell*>(ptr)->QPropertyValueRemovedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyValueRemovedChangeBase *__qt_this = new(__qtjambi_ptr) QPropertyValueRemovedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyValueRemovedChangeBase_shell
void __qt_destruct_Qt3DCore_QPropertyValueRemovedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyValueRemovedChangeBase")
    reinterpret_cast<QPropertyValueRemovedChangeBase_shell*>(ptr)->~QPropertyValueRemovedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyValueRemovedChangeBase_initialize_1native__Lio_qt_qt3d_core_QPropertyValueRemovedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_0, sizeof(QPropertyValueRemovedChangeBase_shell), typeid(Qt3DCore::QPropertyValueRemovedChangeBase), true, &deleter_Qt3DCore_QPropertyValueRemovedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyValueRemovedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyValueRemovedChangeBase>("Qt3DCore::QPropertyValueRemovedChangeBase", "io/qt/qt3d/core/QPropertyValueRemovedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyValueRemovedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_0, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyValueRemovedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPropertyValueRemovedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QPropertyValueRemovedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-5.15.20.jar: sources/QtJambi3DCore/QPropertyValueRemovedChangeBase_shell.cpp <==
#include "QPropertyValueRemovedChangeBase_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyValueRemovedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyValueRemovedChangeBase")
    Qt3DCore::QPropertyValueRemovedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QPropertyValueRemovedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyValueRemovedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyValueRemovedChangeBase_shell) ); }

jmethodID QPropertyValueRemovedChangeBase_shell::__shell_javaMethod(int pos) const { return QPropertyValueRemovedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyValueRemovedChangeBase), pos); }

// emitting (writeShellConstructor)
QPropertyValueRemovedChangeBase_shell::QPropertyValueRemovedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyValueRemovedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QPropertyValueRemovedChangeBase_shell::__shell())
    QPropertyValueRemovedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

// emitting (writeShellDestructor)
QPropertyValueRemovedChangeBase_shell::~QPropertyValueRemovedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::~Qt3DCore::QPropertyValueRemovedChangeBase()", QPropertyValueRemovedChangeBase_shell::__shell())
    QPropertyValueRemovedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

void QPropertyValueRemovedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyValueRemovedChangeBase_shell*>(ptr)->QPropertyValueRemovedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyValueRemovedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyValueRemovedChangeBase *__qt_this = new(__qtjambi_ptr) QPropertyValueRemovedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyValueRemovedChangeBase_initialize_1native__Lio_qt_qt3d_core_QPropertyValueRemovedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyValueRemovedChangeBase::QPropertyValueRemovedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_Qt3DCore_QNodeId, sizeof(QPropertyValueRemovedChangeBase_shell), typeid(Qt3DCore::QPropertyValueRemovedChangeBase), true, &deleter_Qt3DCore_QPropertyValueRemovedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyValueRemovedChangeBase_shell
void __qt_destruct_Qt3DCore_QPropertyValueRemovedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyValueRemovedChangeBase")
    reinterpret_cast<QPropertyValueRemovedChangeBase_shell*>(ptr)->~QPropertyValueRemovedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyValueRemovedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyValueRemovedChangeBase>("Qt3DCore::QPropertyValueRemovedChangeBase", "io/qt/qt3d/core/QPropertyValueRemovedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyValueRemovedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyValueRemovedChangeBase_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyValueRemovedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPropertyValueRemovedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QPropertyValueRemovedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
